

# Copyright (C) 2011-2023 RhodeCode GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License, version 3
# (only), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This program is dual-licensed. If you wish to learn more about the
# RhodeCode Enterprise Edition, including its added features, Support services,
# and proprietary license terms, please see https://rhodecode.com/licenses/

import logging

from rhodecode.apps._base import BaseReferencesView
from rhodecode.lib import ext_json
from rhodecode.lib.auth import (LoginRequired, HasRepoPermissionAnyDecorator)
from rhodecode.model.scm import ScmModel

log = logging.getLogger(__name__)


class RepoTagsView(BaseReferencesView):

    @LoginRequired()
    @HasRepoPermissionAnyDecorator(
        'repository.read', 'repository.write', 'repository.admin')
    def tags(self):
        c = self.load_default_context()
        self._prepare_and_set_clone_url(c)
        c.rhodecode_repo = self.rhodecode_vcs_repo
        c.repository_forks = ScmModel().get_forks(self.db_repo)

        ref_items = self.rhodecode_vcs_repo.tags.items()
        data = self.load_refs_context(
            ref_items=ref_items, partials_template='tags/tags_data.mako')

        c.has_references = bool(data)
        c.data = ext_json.str_json(data)
        return self._get_template_context(c)
